/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure 11:  Specialization patterns by age, US
			
Notes: 		1. Uses data from 1990 Census, 2000 Census
			and 2006--2008 ACS
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/figure_specialization_us.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

use "$project/clean_data/specialization_ipums_us1990.dta", clear
merge 1:1 age using "$project/clean_data/specialization_ipums_us2000.dta", assert(3) nogenerate
merge 1:1 age using "$project/clean_data/specialization_ipums_us2008.dta", assert(3) nogenerate
gen upper_limit=.

* smooth data *
rangestat (mean) *_job*, interval(age -2 2)

**********************************************
********Left Panel of Figure 11***************
**********************************************
* Ratio of white to blue collar jobs *
local var rel_blue_job 
egen `var'_ave=rowmean(`var'_*_mean)
egen `var'_max=rowmax(`var'_*_mean)
quietly: sum `var'_max
replace upper_limit=`r(max)'
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'

twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'_1990_mean age, mcolor(blue%80) msymbol(square) mfcolor(blue%30) mlcolor(black) lcolor(black)) ///
		(connected `var'_2000_mean age, mcolor(red%50) msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'_2008_mean age, mcolor(gold%50) msymbol(circle) mlcolor(black) lcolor(black)) ///
		(connected `var'_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext', size(large)) xtitle(Age, size(large)) xlabel(20(5)80) ///
		legend(ring(0) pos(7) order(2 "1990 Census" 3 "2000 Census" 4 "2006-2008 ACS" 5 "Average") cols(1) rows(4) region(lcolor(white)))  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
		name(`var', replace)

**********************************************
********Right Panel of Figure 11**************
**********************************************		
* Share of employment by age in industries with greatest opportunities for industrial robot usage *
local var rob_ind_job 
egen `var'_ave=rowmean(`var'_*_mean)
egen `var'_max=rowmax(`var'_*_mean)
quietly: sum `var'_max
replace upper_limit=`r(max)'

twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'_1990_mean age, mcolor(blue%80) msymbol(square) mfcolor(blue%30) mlcolor(black) lcolor(black)) ///
		(connected `var'_2000_mean age, mcolor(red%50) msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'_2008_mean age, mcolor(gold%50) msymbol(circle) mlcolor(black) lcolor(black)) ///
		(connected `var'_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(Share of workers in highly robotizable industries, size(large)) xtitle(Age, size(large)) xlabel(20(5)80) ///
		legend(off) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)		
		
gr combine rel_blue_job rob_ind_job , graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) xsize(8) cols(2) title("Comparative advantage patterns by age, US")
graph export "$project/results/figure_specialization_us.pdf", as(pdf)  replace
