/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure 7: 	Relationship between aging and trade of
			different intermediates
			
Notes: 		
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/comtrade_figure_by_categories.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
	
	**************************
	*******Housekeeping*******
	**************************

* order in which commodities will appear in the figure *
local order_commodities subpanelA industrial_robot numerically_controlled machine_tools  automatic_welding weaving_textile dedicated_textile transfer_equipment control_instruments subpanelB capital_goods dedicated_food manual_tools  not_numerically_controlled  manual_machtool  manual_welding  transfer_tools  subpanelC  laundry_machine vending_machine  agriculture_machine  computers 

* create dataset to save estimation results *
tempfile estimates_imports
clear
set obs 30
gen category=""
gen ols_full_b=.
gen ols_full_se=.
gen ols_oecd_b=.
gen ols_oecd_se=.
gen iv_full_b=.
gen iv_full_se=.
gen iv_oecd_b=.
gen iv_oecd_se=.
gen flow="A. Imports"
save `estimates_imports', replace

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* comtrade imports of intermediates *
merge 1:1 isocode using "${project}/clean_data/comtrade_1990_2015.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*compute total imports of intermediate goods*
foreach flow in im_ ex_ re_{
egen intermediate_`flow'90=rowtotal(tv_`flow'agriculture_machine tv_`flow'automatic_welding tv_`flow'capital_goods tv_`flow'computers tv_`flow'control_instruments tv_`flow'dedicated_food tv_`flow'dedicated_textile tv_`flow'industrial_robot tv_`flow'laundry_machine tv_`flow'machine_tools tv_`flow'manual_machtool tv_`flow'manual_tools tv_`flow'manual_welding tv_`flow'none tv_`flow'not_numerically_controlled tv_`flow'numerically_controlled tv_`flow'transfer_equipment tv_`flow'transfer_tools tv_`flow'vending_machine tv_`flow'weaving_textile), missing
}
gen ln_imports=ln(intermediate_im_90)
 
*sample selection*
drop if country_name=="japan"  | country_name=="luxembourg"

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*regions*
encode new_region, gen(dreg)

	************************
	*******Estimation*******
	************************   

**Loop over categories of imports**
local i=1
foreach cat of local  order_commodities {

if "`cat'"=="subpanelA" | "`cat'"=="subpanelB" | "`cat'"=="subpanelC" {
preserve
use `estimates_imports', clear
replace category="ph" in `i'
local i=`i'+1
replace category="`cat'" in `i'
save `estimates_imports', replace
restore
}
else{   
*remove re-exports*
gen net_`cat'=tv_im_`cat'-tv_re_`cat'
gen share_`cat'=1000000*(net_`cat')/(intermediate_im_90) if net_`cat'>=0
replace share_`cat'=ln(share_`cat')

reg share_`cat' change_dependency  $country_covariates_1990 i.dreg $imports90_weights, r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_imports', clear
replace category="`cat'" in `i'
replace flow="A. Imports" in `i'
replace ols_full_b=`beta' in `i'
replace ols_full_se=`serr' in `i'
save `estimates_imports', replace
restore

reg share_`cat' change_dependency   $country_covariates_1990 $imports90_weights  if new_region=="OECD", r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_imports', clear
replace ols_oecd_b=`beta' in `i'
replace ols_oecd_se=`serr' in `i'
save `estimates_imports', replace
restore

ivreg2 share_`cat' (change_dependency=$instruments) $country_covariates_1990 i.dreg $imports90_weights, r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_imports', clear
replace iv_full_b=`beta' in `i'
replace iv_full_se=`serr' in `i'
save `estimates_imports', replace
restore

ivreg2 share_`cat' (change_dependency=$instruments)  $country_covariates_1990 $imports90_weights if new_region=="OECD", r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_imports', clear
replace iv_oecd_b=`beta' in `i'
replace iv_oecd_se=`serr' in `i'
save `estimates_imports', replace
restore
}

local i=`i'+1
}

***EXPORTS FROM COMTRADE***
**Imports by category**
tempfile estimates_exports
clear
set obs 30
gen category=""
gen ols_full_b=.
gen ols_full_se=.
gen ols_oecd_b=.
gen ols_oecd_se=.
gen iv_full_b=.
gen iv_full_se=.
gen iv_oecd_b=.
gen iv_oecd_se=.
gen flow="B. Exports"
save `estimates_exports', replace

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* comtrade imports of intermediates *
merge 1:1 isocode using "${project}/clean_data/comtrade_1990_2015.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*compute total imports of intermediate goods*
foreach flow in im_ ex_ re_{
egen intermediate_`flow'90=rowtotal(tv_`flow'agriculture_machine tv_`flow'automatic_welding tv_`flow'capital_goods tv_`flow'computers tv_`flow'control_instruments tv_`flow'dedicated_food tv_`flow'dedicated_textile tv_`flow'industrial_robot tv_`flow'laundry_machine tv_`flow'machine_tools tv_`flow'manual_machtool tv_`flow'manual_tools tv_`flow'manual_welding tv_`flow'none tv_`flow'not_numerically_controlled tv_`flow'numerically_controlled tv_`flow'transfer_equipment tv_`flow'transfer_tools tv_`flow'vending_machine tv_`flow'weaving_textile), missing
}
gen ln_imports=ln(intermediate_im_90)
 
*sample selection*
drop if country_name=="nigeria"

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*regions*
encode new_region, gen(dreg)

**Loop over exports**
local i=1
foreach cat of local  order_commodities {

if "`cat'"=="subpanelA" | "`cat'"=="subpanelB" | "`cat'"=="subpanelC" {
preserve
use `estimates_exports', clear
replace category="ph" in `i'
local i=`i'+1
replace category="`cat'" in `i'
save `estimates_exports', replace
restore
}
else{ 
*remove re-exports*
gen net_`cat'=tv_ex_`cat'
gen share_`cat'=1000000*(net_`cat')/(intermediate_ex_90) if net_`cat'>=0
replace share_`cat'=ln(share_`cat')

reg share_`cat' change_dependency   $country_covariates_1990 i.dreg $exports90_weights, r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_exports', clear
replace category="`cat'" in `i'
replace flow="B. Exports" in `i'
replace ols_full_b=`beta' in `i'
replace ols_full_se=`serr' in `i'
save `estimates_exports', replace
restore

reg share_`cat' change_dependency   $country_covariates_1990 $exports90_weights if new_region=="OECD", r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_exports', clear
replace ols_oecd_b=`beta' in `i'
replace ols_oecd_se=`serr' in `i'
save `estimates_exports', replace
restore

ivreg2 share_`cat' (change_dependency=$instruments)   $country_covariates_1990 i.dreg $exports90_weights, r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_exports', clear
replace iv_full_b=`beta' in `i'
replace iv_full_se=`serr' in `i'
save `estimates_exports', replace
restore

ivreg2 share_`cat' (change_dependency=$instruments)   $country_covariates_1990 i.dreg $exports90_weights if new_region=="OECD", r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use `estimates_exports', clear
replace iv_oecd_b=`beta' in `i'
replace iv_oecd_se=`serr' in `i'
save `estimates_exports', replace
restore
}

local i=`i'+1
}


use `estimates_imports', clear
drop if cat==""
gen base_num=_n
expand 3
sort base_num
gen number=76-_n
save `estimates_imports', replace

use `estimates_exports', clear
drop if cat==""
gen base_num=_n
expand 3
sort base_num
gen number=76-_n
save `estimates_exports', replace

use `estimates_imports', clear
append using `estimates_exports'

*label panels*
replace category="..." if category=="ph"
replace category="Group 1: industrial automation" if category=="subpanelA" 
replace category="Group 2: other capital goods" if category=="subpanelB"
replace category="Group 3: not industrial" if category=="subpanelC"

*label categories*
replace category="Dedicated machinery (inc. robots)" if category=="industrial_robot" /*Dedicated machinery (in HS robots also reported here)*/
replace category="Numerically controlled machines" if category=="numerically_controlled" /*Numerically controlled machines*/ 
replace category="Automatic welding machines" if category=="automatic_welding" /*Automatic welding machines*/
replace category="Weaving and knitting machines" if category=="weaving_textile" /*Spinning, weaving and knitting machines used in textiles*/ 
replace category="Other textile dedicated machinery" if category=="dedicated_textile" /*Dedicated machinery used in textiles*/
replace category="Automatic machine tools" if category=="machine_tools" /**/  
replace category="Regulating and control instruments" if category=="control_instruments" /**/  
replace category="Automatic conveyors" if category=="transfer_equipment" /**/ 

replace category="Tools for industrial work" if category=="manual_tools" /*Tools (includes only those with industrial uses)*/
replace category="Manual machine tools" if category=="manual_machtool" /**/ 
replace category="Manual welding machines" if category=="manual_welding" /**/ 
replace category="Not-numerically controlled vintages" if category=="not_numerically_controlled" /*Machines that are not numerically controlled, but that variants of them are numerically controlled*/  
replace category="Tools for transferring materials" if category=="transfer_tools" /**/ 
replace category="Heavy capital goods" if category=="capital_goods" /*Other industrial machinery not classified (excluding computers and electronic parts)*/ 
replace category="Food manufacturing" if category=="dedicated_food" /*Baking and Brewing equipment for industrial use*/

replace category="Laundry machines" if category=="laundry_machine" /*Laundry machines*/
replace category="Vending machines" if category=="vending_machine" /*Vending machines*/
replace category="Agricultural machinery" if category=="agriculture_machine" /*Machines used in agricultural production*/
replace category="Computers" if category=="computers" /*Computers*/

replace category=" " if number==3*floor(number/3)+1
replace category=" " if number==3*floor(number/3)

gen full_sample=1 if  number==3*floor(number/3)+2
gen oecd_sample=1 if  number==3*floor(number/3)+1

drop if number>=72

labmask number, values(category)

gen iv_full_low=iv_full_b-1.65*iv_full_se
gen iv_full_high=iv_full_b+1.65*iv_full_se

gen iv_oecd_low=iv_oecd_b-1.65*iv_oecd_se
gen iv_oecd_high=iv_oecd_b+1.65*iv_oecd_se

twoway 	(bar iv_full_b number if full_sample==1, sort fcolor(white) fintensity(20) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap    iv_full_low iv_full_high number if full_sample==1, sort lcolor(black) lwidth(vthin) horizontal msize(vsmall)) ///
		(scatter number iv_full_b if full_sample==1, mcolor(black) lcolor(black) msize(*.15)) ///
		(bar iv_oecd_b number if oecd_sample==1, sort fcolor(dkorange) fintensity(80) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap iv_oecd_low iv_oecd_high number if oecd_sample==1, sort lcolor(black) lwidth(vthin) horizontal msize(vsmall)) ///
		(scatter number iv_oecd_b if oecd_sample==1, mcolor(black) lcolor(black) msize(*.15)), ///
		legend(symysize(*.3) symxsize(*.6) order(1 "Full sample" 4 "OECD sample") region(lcolor(none)) bmargin(zero) size(small) ) ysize(8) xsize(10) ytitle("") yscale(noline) /// 
		ylabel(2(3)71, labels labsize(small) angle(horizontal) valuelabel noticks grid glpattern(solid) glcolor(gs12) glwidth(vvthin) nogextend) ///
		xtitle("")  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(lcolor(white) lwidth(vthin)) xline(0, lcolor(black) lwidth(vthin)) ///
		by(flow, note("") noiytick xrescale legend(on position(5))  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(lcolor(white) lwidth(vthin))) subtitle(, margin(medium) nobox)
graph export "$project/results/comtrade_figure_by_categories.pdf", as(pdf)  replace

