/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure A5: 	Robustness patents
			
Notes: 		
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/patents_robustness.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* program to remove outliers *
cap program drop reg_outliers
program define reg_outliers, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	reg `y_vars' `x_var' `controls'  `wt'  if `cons_sample'==1, r
end

* loop over sample (oecd, full)
foreach sample in full oecd {

* create dataset to save estimation results *
preserve
clear
set obs 20
gen category=""
gen spec1_b=.
gen spec1_se=.
gen spec2_b=.
gen spec2_se=.
gen spec3_b=.
gen spec3_se=.
gen spec4_b=.
gen spec4_se=.
gen sample="`sample'"
save "$project/temp_data/estimates_`sample'.dta", replace
restore

	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* patent data---drop others category *
merge 1:1 isocode using "${project}/clean_data/country_patents.dta", keep(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg)

*dependent variable*
gen ln_patents=ln(t_utility_patents)

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)
  
if "`sample'"=="oeced"{
keep if new_region=="OECD"
}

	************************
	*******Estimation*******
	************************   

* Loop over different types of patents *
local i=1
foreach cat in  subpanelA automation_rel automation_901 automation_crossref25 automation_crossref10 words_robot words_ind_robot words_robot_manipulator words_numcontrol subpanelB class_comp words_computer class_soft words_software class_nano words_nano class_pharm words_pharma   {

if "`cat'"=="subpanelA" | "`cat'"=="subpanelB" | "`cat'"=="subpanelC" {
preserve
use "$project/temp_data/estimates_`sample'.dta", clear
replace category="ph" in `i'
local i=`i'+1
replace category="`cat'" in `i'
save "$project/temp_data/estimates_`sample'.dta", replace
restore
}
else{
**Specification 1: baseline*
gen depvar1_`cat'=ln(`cat')
reg depvar1_`cat'  change_dependency  $country_covariates_1990 i.dreg $patent_weights, r
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use "$project/temp_data/estimates_`sample'.dta", clear
replace category="`cat'" in `i'
replace spec1_b=`beta' in `i'
replace spec1_se=`serr' in `i'
save "$project/temp_data/estimates_`sample'.dta", replace
restore

**Specification 2: log(1+share) or Poisson*
gen depvar2_`cat'=ln(1000*`cat'+1)
ivreg2 depvar2_`cat'  (change_dependency=$instruments)  $country_covariates_1990 i.dreg $patent_weights, r
*cap ivpoisson gmm depvar3_`cat'  (change_dependency=$instruments ) ln_patents $country_covariates_1990 i.dreg $patent_weights, iter(10)
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use "$project/temp_data/estimates_`sample'.dta", clear
replace spec2_b=`beta' in `i'
replace spec2_se=`serr' in `i'
save "$project/temp_data/estimates_`sample'.dta", replace
restore

**Specification 3: share *
gen depvar3_`cat'=`cat' 
ivreg2 depvar3_`cat'  (change_dependency=$instruments)  $country_covariates_1990 i.dreg $patent_weights, r
sum depvar3_`cat' if e(sample) $patent_weights
local beta=_b[change_dependency]/r(mean)
local serr=_se[change_dependency]/r(mean)
preserve
use "$project/temp_data/estimates_`sample'.dta", clear
replace spec3_b=`beta' in `i'
replace spec3_se=`serr' in `i'
save "$project/temp_data/estimates_`sample'.dta", replace
restore

**Specification 4: remove outliers*
gen depvar4_`cat'=ln(`cat')
reg_outliers depvar4_`cat' change_dependency $patent_weights, controls($country_covariates_1990 i.dreg)
local beta=_b[change_dependency]
local serr=_se[change_dependency]
preserve
use "$project/temp_data/estimates_`sample'.dta", clear
replace spec4_b=`beta' in `i'
replace spec4_se=`serr' in `i'
replace sample="`sample'" in `i'
save "$project/temp_data/estimates_`sample'.dta", replace
restore
}

local i=`i'+1
}
}



use "$project/temp_data/estimates_full.dta", clear
drop if cat==""
gen base_num=_n
expand 5
sort base_num
gen number=101-_n
save "$project/temp_data/estimates_full.dta", replace

use "$project/temp_data/estimates_oecd.dta", clear
drop if cat==""
gen base_num=_n
expand 5
sort base_num
gen number=101-_n
save "$project/temp_data/estimates_oecd.dta", replace

use "$project/temp_data/estimates_full.dta", clear
append using "$project/temp_data/estimates_oecd.dta"

*label panels*
replace sample="A. Full sample" if sample=="full"
replace sample="B. OECD sample" if sample=="oecd"

replace category="..." if category=="ph"
replace category="Group 1: related to industrial automation" if category=="subpanelA" 
replace category="Group 2: Panel--other technology classes" if category=="subpanelB"


*label categories* words_sensor words_comp words_soft words_nano words_pharma  
replace category="Classes related to 901" if category=="automation_rel"
replace category="Classes referencing 901 (25% threshold)" if category=="automation_crossref25" 
replace category="Classes referencing 901 (10% threshold)" if category=="automation_crossref10" 
replace category="901 USPTO class" if category=="automation_901" 
replace category="Words related to robots" if category=="words_robot"  
replace category="Words related to industrial robots" if category=="words_ind_robot"   
replace category="Words related to robots and manipulators" if category=="words_robot_manipulator" /**/ 
replace category="Words related to numerical control" if category=="words_numcontrol"  
replace category="Classes related to computers" if category=="class_comp"  
replace category="Words related to computers" if category=="words_computer"  
replace category="Classes related to software" if category=="class_soft"
replace category="Words related to software" if category=="words_software"
replace category="Classes related to nanotechnology" if category=="class_nano"  
replace category="Words related to nanotechnology" if category=="words_nano"
replace category="Classes related to pharmaceuticals" if category=="class_pharm"  
replace category="Words related to pharmaceuticals" if category=="words_pharma"


replace category=" " if number!=5*floor(number/5)+4

gen estimator_1=1 if number==5*floor(number/5)+4
gen estimator_2=1 if number==5*floor(number/5)+3
gen estimator_3=1 if number==5*floor(number/5)+2
gen estimator_4=1 if number==5*floor(number/5)+1


labmask number, values(category)

forvalues j=1(1)4{
gen spec`j'_low =spec`j'_b-1.65*spec`j'_se
gen spec`j'_high=spec`j'_b+1.65*spec`j'_se

*Truncating things so that they fit into the full figure*
replace spec`j'_low =. if spec`j'_low<-5
replace spec`j'_high =. if spec`j'_high>3



}

* plot figure *
drop if number>94
twoway 	(bar     spec1_b number if estimator_1==1, sort fcolor(white) fintensity(0) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap    spec1_low spec1_high number if estimator_1==1, sort lcolor(gs2) lwidth(vvthin) horizontal msize(vsmall)) ///
		(bar     spec2_b number if estimator_2==1, sort fcolor(dkorange) fintensity(30) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap    spec2_low spec2_high number if estimator_2==1, sort lcolor(gs2) lwidth(vvthin) horizontal msize(vsmall)) ///
		(bar     spec3_b number if estimator_3==1, sort fcolor(cranberry) fintensity(60) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap    spec3_low spec3_high number if estimator_3==1, sort lcolor(gs2) lwidth(vvthin) horizontal msize(vsmall)) ///
		(bar     spec4_b number if estimator_4==1, sort fcolor(dkorange) fintensity(100) lcolor(black) lwidth(vthin) horizontal barwidth(0.8)) ///
		(rcap    spec4_low spec4_high number if estimator_4==1, sort lcolor(gs2) lwidth(vvthin) horizontal msize(vsmall)), ///
		legend(symysize(*.3) symxsize(*.6) rows(4)  order(1 "baseline (OLS)" 3 "log one plus share" 5 "share" 7 "exclude outliers") region(lcolor(none)) bmargin(zero) size(vsmall) ) ysize(8) xsize(14) ytitle("") yscale(noline) /// 
		ylabel(4(5)94, labels labsize(small) angle(horizontal) valuelabel noticks grid glpattern(solid) glcolor(gs12) glwidth(vvthin) nogextend) ///
		xtitle("")  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(lcolor(white) lwidth(vthin)) xline(0, lcolor(black) lwidth(vthin)) ///
		by(sample, note("") noiytick xrescale legend(on position(4))  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(lcolor(white) lwidth(vthin))) subtitle(, margin(medium) nobox)
	graph export "$project/results/patents_robustness.pdf", as(pdf)  replace

