/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table 5: 	Estimates of the impact of aging on patents
			related to robotics
			
Notes: 		
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_patents_ols.tex			
			/results/table_patents_iv.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* patent data---drop others category *
merge 1:1 isocode using "${project}/clean_data/country_patents.dta", keep(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

* regions *
encode new_region, gen(dreg)

* dependent variable *
gen share_robots=ln(automation_rel) /*ln of share of robotics-related patents */
gen ln_patents=ln(t_utility_patents)

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*define sample*
quietly: reg share_robots  change_dependency   $country_covariates_1990 i.dreg $patent_weights , r
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

*****************************************************************************************
************************Table 5, Panel A: OLS models, weighted **************************
*****************************************************************************************
reg share_robots  change_dependency   i.dreg $patent_weights if full_sample, r
estimates store e1

* computing partial r-square reported in the paper *
reg share_robots i.dreg if full_sample $patent_weights
predict change_y, resid
reg change_dep i.dreg if full_sample $patent_weights
predict change_x, resid
reg change_y change_x if full_sample $patent_weights, r


reg share_robots  change_dependency   $country_covariates_1990 i.dreg $patent_weights if full_sample, r
estimates store e2

reg share_robots  change_dependency   ln_manuf_va ln_patents $country_covariates_1990 i.dreg $patent_weights if full_sample, r
estimates store e3

reg share_robots  change_dependency   $patent_weights if new_region=="OECD", r
estimates store e4

reg share_robots  change_dependency   $country_covariates_1990 $patent_weights if new_region=="OECD", r
estimates store e5

reg share_robots  change_dependency   ln_manuf_va ln_patents $country_covariates_1990 $patent_weights if new_region=="OECD", r
estimates store e6

estout e1 e2 e3 e4 e5 e6  using "$project/results/table_patents_ols.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep( change_dependency) ///
order(change_dependency) 


*****************************************************************************************
************************Table 5, Panel B: IV models, weighted ***************************
*****************************************************************************************
ivreg2 share_robots  (change_dependency=$instruments )   i.dreg $patent_weights if full_sample, r ffirst
estimates store e1

ivreg2 share_robots  (change_dependency=$instruments )   $country_covariates_1990 i.dreg $patent_weights if full_sample, r ffirst
estimates store e2

ivreg2 share_robots  (change_dependency=$instruments )   ln_manuf_va ln_patents $country_covariates_1990 i.dreg $patent_weights if full_sample, r ffirst
estimates store e3

ivreg2 share_robots  (change_dependency=$instruments )   $patent_weights if new_region=="OECD", r ffirst
estimates store e4

ivreg2 share_robots  (change_dependency=$instruments )   $country_covariates_1990 $patent_weights if new_region=="OECD", r ffirst
estimates store e5

ivreg2 share_robots  (change_dependency=$instruments )   ln_manuf_va ln_patents $country_covariates_1990 $patent_weights if new_region=="OECD", r ffirst
estimates store e6

estout e1 e2 e3 e4 e5 e6  using "$project/results/table_patents_iv.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep( change_dependency) ///
order(change_dependency) 
