/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table 8: 	Estimates of the impact of aging on the value
			added of country-industry pairs per year
			
Notes: 		
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_industry_klems_vadded.tex
            /results/table_industry_iv_klems_vadded.tex
			/results/table_industry_klems_labsh.tex
			/results/table_industry_iv_klems_labsh

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* start from klems data *	
use "${project}/clean_data/country_industry_klems.dta", clear

* merge covariates *
merge m:1 isocode using "$project/clean_data/country_covariates.dta", assert(2 3) keep(3) nogenerate

* demographics variables *
merge m:1 isocode using "${project}/clean_data/country_demographics.dta", assert(2 3) keep(3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

* merge industry characteristics *
merge m:1 industry_ifr using "${project}/clean_data/replaceability_ifr19.dta", assert(3) nogenerate
merge m:1 industry_ifr using "${project}/clean_data/uscensus_industry_1990", nogenerate
merge m:1 industry_ifr using "${project}/clean_data/uscensus_industry_2000", nogenerate
gen routine_bcg=0
replace routine_bcg=1 if industry_ifr=="automotive"
replace routine_bcg=1 if industry_ifr=="electronics"
replace routine_bcg=1 if industry_ifr=="metal_machinery"
replace routine_bcg=1 if industry_ifr=="plastic_chemicals"

* Define units *
encode isocode, gen(cty_code)
egen cell_code=group(isocode industry_ifr)
encode industry_ifr, gen(industry_code)

* restrict to sample of countries analyzed on Table 6 *
drop if isocode=="JPN" 

* weights *
bys isocode: egen total_wt=total(klems_engaged_1995)
gen altwts=klems_engaged_1995/total_wt

*Interactions: evaluated at mean *
gen young_intensity_raw=(1-share_55_emp_1990)/share_55_emp_1990
sum young_intensity_raw [w=altwts], d
gen young_intensity=young_intensity_raw-r(mean)

gen routine_intensity_rep=replaceable  
sum routine_intensity_rep [w=altwts], d
replace routine_intensity_rep=routine_intensity_rep-r(mean)

gen routine_intensity_bcg=routine_bcg
sum routine_intensity_bcg [w=altwts], d
replace routine_intensity_bcg=routine_intensity_bcg-r(mean)

*dependency (since 1995) *
gen change_dependency=(${aging_measure}2025-${aging_measure}1995)

gen indbase1995_output=ln(klems_labprod_1995)

	************************
	*******Estimation*******
	************************ 
	
*********************************************************************************************
**************Table 8, Panel A: OLS models for value-added per worker ***********************
*********************************************************************************************

* construct change in value added per worker from 1995--2007 (or earlier years if data missing) *
gen depvart_2007=ln(klems_labprod_2007)-ln(klems_labprod_1995)
replace depvart_2007=(ln(klems_labprod_2006)-ln(klems_labprod_1995))*12/11 if  depvart_2007==.
replace depvart_2007=(ln(klems_labprod_2005)-ln(klems_labprod_1995))*12/10 if  depvart_2007==.

reg depvart_2007	change_dependency i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep
reg depvart_2007	change_dependency c.change_dependency#c.(prone_robots young_intensity) i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e2

reg depvart_2007	change_dependency c.change_dependency#c.(prone_robots young_intensity) indbase1995_output i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e3

reg depvart_2007	c.change_dependency#c.(prone_robots young_intensity) indbase1995_output i.cty_code i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg
reg depvart_2007	change_dependency c.change_dependency#c.(prone_robots young_intensity) i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e5

reg depvart_2007	change_dependency c.change_dependency#c.(prone_robots young_intensity) indbase1995_output i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e6

reg depvart_2007	c.change_dependency#c.(prone_robots young_intensity) indbase1995_output i.cty_code i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e7

* export the table *
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_industry_klems_vadded.tex", style(tex) ///
varlabels(change_dependency "Aging between 1995 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust, fmt(%7.0f %7.0f %7.2f) labels("Observations" "Countries in sample" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots)

*********************************************************************************************
***************Table 8, Panel B: IV models for value-added per worker ***********************
*********************************************************************************************
ivreg2 depvart_2007	(change_dependency=$instruments) i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(i.industry_code##c.($industry_covariates_1995))
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep 
ivreg2 depvart_2007	(change_dependency c.change_dependency#c.(prone_robots young_intensity)=$instruments c.($instruments )#c.(young_intensity prone_robots)) ///
							i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(i.industry_code##c.($industry_covariates_1995))
estimates store e2

ivreg2 depvart_2007	(change_dependency c.change_dependency#c.(prone_robots young_intensity)=$instruments c.($instruments )#c.(young_intensity prone_robots)) ///
							indbase1995_output i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(indbase1995_output i.industry_code##c.($industry_covariates_1995))
estimates store e3

ivreg2 depvart_2007	(c.change_dependency#c.(prone_robots young_intensity)=c.($instruments )#c.(young_intensity prone_robots)) ///
							indbase1995_output i.cty_code i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(i.cty_code indbase1995_output i.industry_code##c.($industry_covariates_1995))
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg 
ivreg2 depvart_2007	(change_dependency c.change_dependency#c.(prone_robots young_intensity)=$instruments c.($instruments )#c.(young_intensity prone_robots)) ///
							i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(i.industry_code##c.($industry_covariates_1995))
estimates store e5

ivreg2 depvart_2007	(change_dependency c.change_dependency#c.(prone_robots young_intensity)=$instruments c.($instruments )#c.(young_intensity prone_robots)) ///
							indbase1995_output i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(indbase1995_output i.industry_code##c.($industry_covariates_1995))
estimates store e6

ivreg2 depvart_2007	(c.change_dependency#c.(prone_robots young_intensity)=c.($instruments )#c.(young_intensity prone_robots)) ///
							indbase1995_output i.cty_code i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(i.cty_code indbase1995_output i.industry_code##c.($industry_covariates_1995))
estimates store e7

* export the table *
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_industry_iv_klems_vadded.tex", style(tex) ///
varlabels(change_dependency "Aging between 1995 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		   cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust  widstat jp, fmt(%7.0f %7.0f  %7.2f %7.2f) labels("Observations" "Countries in sample"  "First-stage $ F$ stat." "Overid p-value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) 

drop  depvart_2007 

*********************************************************************************************
**************Table 8, Panel C: OLS models for the labor share        ***********************
*********************************************************************************************

* construct change in labor share from 1995--2007 (or earlier years if data missing) *
gen depvart_2007=klems_labsh_2007-klems_labsh_1995
replace depvart_2007=(klems_labsh_2006-klems_labsh_1995)*12/11 if  depvart_2007==.
replace depvart_2007=(klems_labsh_2005-klems_labsh_1995)*12/10 if  depvart_2007==.

reg depvart_2007	change_dependency i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep
reg depvart_2007	change_dependency c.change_dependency#c.(prone_robots young_intensity) i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e2

reg depvart_2007	change_dependency c.change_dependency#c.(prone_robots young_intensity) indbase1995_output i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e3

reg depvart_2007	c.change_dependency#c.(prone_robots young_intensity) indbase1995_output i.cty_code i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg
reg depvart_2007	change_dependency c.change_dependency#c.(prone_robots young_intensity) i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e5

reg depvart_2007	change_dependency c.change_dependency#c.(prone_robots young_intensity) indbase1995_output i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e6

reg depvart_2007	c.change_dependency#c.(prone_robots young_intensity) indbase1995_output i.cty_code i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code)
estimates store e7

* export the table *
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_industry_klems_labsh.tex", style(tex) ///
varlabels(change_dependency "Aging between 1995 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust, fmt(%7.0f %7.0f %7.2f) labels("Observations" "Countries in sample" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots)

*********************************************************************************************
**************Table 8, Panel D: IV models for the labor share         ***********************
*********************************************************************************************
ivreg2 depvart_2007	(change_dependency=$instruments) i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(i.industry_code##c.($industry_covariates_1995))
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep 
ivreg2 depvart_2007	(change_dependency c.change_dependency#c.(prone_robots young_intensity)=$instruments c.($instruments )#c.(young_intensity prone_robots)) ///
							i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(i.industry_code##c.($industry_covariates_1995))
estimates store e2

ivreg2 depvart_2007	(change_dependency c.change_dependency#c.(prone_robots young_intensity)=$instruments c.($instruments )#c.(young_intensity prone_robots)) ///
							indbase1995_output i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(indbase1995_output i.industry_code##c.($industry_covariates_1995))
estimates store e3

ivreg2 depvart_2007	(c.change_dependency#c.(prone_robots young_intensity)=c.($instruments )#c.(young_intensity prone_robots)) ///
							indbase1995_output i.cty_code i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(i.cty_code indbase1995_output i.industry_code##c.($industry_covariates_1995))
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg 
ivreg2 depvart_2007	(change_dependency c.change_dependency#c.(prone_robots young_intensity)=$instruments c.($instruments )#c.(young_intensity prone_robots)) ///
							i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(i.industry_code##c.($industry_covariates_1995))
estimates store e5

ivreg2 depvart_2007	(change_dependency c.change_dependency#c.(prone_robots young_intensity)=$instruments c.($instruments )#c.(young_intensity prone_robots)) ///
							indbase1995_output i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(indbase1995_output i.industry_code##c.($industry_covariates_1995))
estimates store e6

ivreg2 depvart_2007	(c.change_dependency#c.(prone_robots young_intensity)=c.($instruments )#c.(young_intensity prone_robots)) ///
							indbase1995_output i.cty_code i.industry_code##c.($industry_covariates_1995) [w=altwts], r cluster(cty_code) partial(i.cty_code indbase1995_output i.industry_code##c.($industry_covariates_1995))
estimates store e7

* export the table *
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_industry_iv_klems_labsh.tex", style(tex) ///
varlabels(change_dependency "Aging between 1995 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		   cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust  widstat jp, fmt(%7.0f %7.0f  %7.2f %7.2f) labels("Observations" "Countries in sample"  "First-stage $ F$ stat." "Overid p-value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) 

