/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A12: 	OLS estimates of expected and contemporaneous aging
			on the adoption of industrial robots
			
Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_timing_future.tex
			/results/table_timing_future_weighted.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen current_dependency=(${aging_measure}2015-${aging_measure}1990)
gen future_dependency=(${aging_measure}2025-${aging_measure}2015)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

*****************************************************************************************	
******Table A12, Panel A: OLS models, current aging vs expected aging (unweighted) ******
*****************************************************************************************

reg change_robots 	current_dependency future_dependency i.dreg if full_sample, r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e1

reg change_robots 	current_dependency future_dependency $country_covariates i.dreg if full_sample, r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e2

reg change_robots 	current_dependency future_dependency ln_manuf_va  base1993_stock_pc $country_covariates i.dreg if full_sample, r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e3

reg change_robots 	current_dependency future_dependency i.dreg if new_region=="OECD", r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e4

reg change_robots 	current_dependency future_dependency $country_covariates i.dreg if new_region=="OECD", r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e5

reg change_robots 	current_dependency future_dependency ln_manuf_va  base1993_stock_pc $country_covariates i.dreg if new_region=="OECD", r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_timing_future.tex", style(tex) ///
varlabels(current_dependency    "Aging between 1990 and 2015"    ///
          future_dependency     "Aging between 2015 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(pval N r2 , fmt(%7.2f %7.0f %7.2f) labels("Test for equality" "Observations" "R-squared" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(current_dependency future_dependency) ///
order(current_dependency future_dependency)

*****************************************************************************************	
******Table A12, Panel B: OLS models, current aging vs expected aging (weighted) ********
*****************************************************************************************

reg change_robots 	current_dependency future_dependency i.dreg if full_sample $robot_weight, r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e1

reg change_robots 	current_dependency future_dependency $country_covariates i.dreg if full_sample $robot_weight, r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e2

reg change_robots 	current_dependency future_dependency ln_manuf_va  base1993_stock_pc $country_covariates i.dreg if full_sample $robot_weight, r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e3

reg change_robots 	current_dependency future_dependency i.dreg if new_region=="OECD" $robot_weight, r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e4

reg change_robots 	current_dependency future_dependency $country_covariates i.dreg if new_region=="OECD" $robot_weight, r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e5

reg change_robots 	current_dependency future_dependency ln_manuf_va  base1993_stock_pc $country_covariates i.dreg if new_region=="OECD" $robot_weight, r
test _b[future_dependency]==_b[current_dependency]
estadd scalar pval=r(p)
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_timing_future_weighted.tex", style(tex) ///
varlabels(current_dependency    "Aging between 1990 and 2015"    ///
          future_dependency     "Aging between 2015 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(pval N r2 , fmt(%7.2f %7.0f %7.2f) labels("Test for equality" "Observations" "R-squared" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(current_dependency future_dependency) ///
order(current_dependency future_dependency)

