/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A13: 	Estimates of the impact of aging between 1990 and
			2015 on the adoption of industrial robots
			
Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_2015_ols.tex
			/results/table_2015_ols_weighted.tex
			/results/table_2015_iv.tex
			/results/table_2015_iv_weighted.tex
			/results/table_2015_single_iv.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2015-${aging_measure}1990)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

*****************************************************************************************	
*****************Table A13, Panel A: OLS models, unweighted *****************************
*****************************************************************************************

reg change_robots 	change_dependency i.dreg if full_sample, r
estimates store e1

reg change_robots 	change_dependency i.dreg $country_covariates if full_sample, r
estimates store e2

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
estimates store e3

reg change_robots 	change_dependency if new_region=="OECD", r
estimates store e4

reg change_robots 	change_dependency $country_covariates  if new_region=="OECD", r
estimates store e5

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD", r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_2015_ols.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2015" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency )


*****************************************************************************************	
*****************Table A13, Panel D: OLS models, weighted *******************************
*****************************************************************************************

reg change_robots 	change_dependency i.dreg if full_sample $robot_weight, r
estimates store e1

reg change_robots 	change_dependency i.dreg $country_covariates if full_sample $robot_weight, r
estimates store e2

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r
estimates store e3

reg change_robots 	change_dependency if new_region=="OECD" $robot_weight, r
estimates store e4

reg change_robots 	change_dependency $country_covariates  if new_region=="OECD" $robot_weight, r
estimates store e5

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD" $robot_weight, r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_2015_ols_weighted.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2015" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency )

*****************************************************************************************	
*****************Table A13, Panel B: IV models, unweighted ******************************
*****************************************************************************************

ivreg2 change_robots 	(change_dependency=$instruments ) i.dreg if full_sample, r partial(i.dreg) ffirst
estimates store e1

ivreg2 change_robots 	(change_dependency=$instruments ) i.dreg $country_covariates if full_sample, r partial(i.dreg) ffirst
estimates store e2

ivreg2 change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r partial(i.dreg) ffirst
estimates store e3

ivreg2 change_robots 	(change_dependency=$instruments ) if new_region=="OECD", r  ffirst
estimates store e4

ivreg2 change_robots 	(change_dependency=$instruments ) $country_covariates if new_region=="OECD", r  ffirst
estimates store e5

ivreg2 change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r  ffirst
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_2015_iv.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2015" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)

*****************************************************************************************	
*****************Table A13, Panel E: IV models, weighted ********************************
*****************************************************************************************

ivreg2 change_robots 	(change_dependency=$instruments ) i.dreg if full_sample $robot_weight, r partial(i.dreg) ffirst
estimates store e1

ivreg2 change_robots 	(change_dependency=$instruments ) i.dreg $country_covariates if full_sample $robot_weight, r partial(i.dreg) ffirst
estimates store e2

ivreg2 change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r partial(i.dreg) ffirst
estimates store e3

ivreg2 change_robots 	(change_dependency=$instruments ) if new_region=="OECD" $robot_weight, r  ffirst
estimates store e4

ivreg2 change_robots 	(change_dependency=$instruments ) $country_covariates if new_region=="OECD" $robot_weight, r  ffirst
estimates store e5

ivreg2 change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" $robot_weight, r ffirst
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_2015_iv_weighted.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2015" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)

*****************************************************************************************	
*************Table A13, Panel C: single IV models, unweighted ***************************
*****************************************************************************************

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) i.dreg if full_sample, r partial(i.dreg)
estimates store e1

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) i.dreg $country_covariates if full_sample, r partial(i.dreg)
estimates store e2

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r partial(i.dreg)
estimates store e3

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) if new_region=="OECD", r 
estimates store e4

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) $country_covariates if new_region=="OECD", r 
estimates store e5

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r 
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_2015_single_iv.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2015" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f) labels("Observations" "First-stage $ F$  stat."  )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)







