/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A15: 	Estimates of the impact of aging on the percent
			increase in robots by country
			
Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_spec_ols.tex
			/results/table_spec_iv.tex
			/results/table_spec_single_iv.tex
			/results/table_spec_ols_weighted.tex
			/results/table_spec_iv_weighted.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 

*robot variables*
gen base1993_stock_pc=ln(stock_robots_1993/$normalization_robots)
gen change_robots=ln(stock_robots_2014/$normalization_robots )-ln(stock_robots_1993/$normalization_robots )

	************************
	*******Estimation*******
	************************   

***Change in logs, Panel A***
reg change_robots change_dependency base1993_stock_pc, r
estimates store e1

reg change_robots change_dependency base1993_stock_pc  $country_covariates , r
estimates store e2

reg change_robots change_dependency ln_manuf_va base1993_stock_pc  $country_covariates , r
estimates store e3

***Change in logs, Panel B***
ivreg2 change_robots (change_dependency=$instruments) base1993_stock_pc, r partial(base1993_stock_pc) ffirst
estimates store e1iv

ivreg2 change_robots (change_dependency=$instruments) base1993_stock_pc  $country_covariates , r partial(base1993_stock_pc  $country_covariates) ffirst
estimates store e2iv

ivreg2 change_robots (change_dependency=$instruments) ln_manuf_va  base1993_stock_pc  $country_covariates , r  partial(ln_manuf_va  base1993_stock_pc  $country_covariates) ffirst
estimates store e3iv

***Change in logs, Panel C***
ivreg2 change_robots (change_dependency=change_birthrate_60_80) base1993_stock_pc, r partial(base1993_stock_pc)
estimates store e1siv

ivreg2 change_robots (change_dependency=change_birthrate_60_80) base1993_stock_pc  $country_covariates , r partial(base1993_stock_pc  $country_covariates)
estimates store e2siv

ivreg2 change_robots (change_dependency=change_birthrate_60_80) ln_manuf_va  base1993_stock_pc  $country_covariates , r partial(ln_manuf_va  base1993_stock_pc  $country_covariates)
estimates store e3siv

*robot variables*
cap drop base1993* change_robots
gen base1993_stock_pc=ln((stock_robots_1993+1)/$normalization_robots)
gen change_robots=ln((stock_robots_2014+1)/$normalization_robots )-ln((stock_robots_1993+1)/$normalization_robots )
quietly: reg change_robots change_dependency base1993_stock_pc i.dreg $country_covariates
gen new_sample=e(sample)

***Change in logs, Panel A***
reg change_robots change_dependency base1993_stock_pc i.dreg if new_sample==1, r
estimates store e4

reg change_robots change_dependency base1993_stock_pc i.dreg $country_covariates  if new_sample==1, r
estimates store e5

reg change_robots change_dependency ln_manuf_va base1993_stock_pc i.dreg $country_covariates  if new_sample==1, r
estimates store e6


***Change in logs, Panel B***
ivreg2 change_robots (change_dependency=$instruments) base1993_stock_pc i.dreg  if new_sample==1, r partial(base1993_stock_pc i.dreg) ffirst
estimates store e4iv

ivreg2 change_robots (change_dependency=$instruments) base1993_stock_pc i.dreg $country_covariates  if new_sample==1, r partial(base1993_stock_pc i.dreg $country_covariates) ffirst
estimates store e5iv

ivreg2 change_robots (change_dependency=$instruments) ln_manuf_va base1993_stock_pc i.dreg $country_covariates  if new_sample==1, r partial(ln_manuf_va base1993_stock_pc i.dreg $country_covariates) ffirst
estimates store e6iv


***Change in logs, Panel C***
ivreg2 change_robots (change_dependency=change_birthrate_60_80) base1993_stock_pc if new_sample==1, r partial(base1993_stock_pc)
estimates store e4siv

ivreg2 change_robots (change_dependency=change_birthrate_60_80) base1993_stock_pc  $country_covariates  if new_sample==1, r partial(base1993_stock_pc  $country_covariates)
estimates store e5siv

ivreg2 change_robots (change_dependency=change_birthrate_60_80) ln_manuf_va base1993_stock_pc  $country_covariates  if new_sample==1, r partial(ln_manuf_va base1993_stock_pc  $country_covariates)
estimates store e6siv

*****************************************************************************************	
*****************Table A15, Panel A: OLS models, unweighted *****************************
*****************************************************************************************

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_spec_ols.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency )

*****************************************************************************************	
*****************Table A15, Panel B: IV models, unweighted *****************************
*****************************************************************************************

*Export tables*
estout e1iv e2iv e3iv e4iv e5iv e6iv using  "$project/results/table_spec_iv.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency )

*****************************************************************************************	
***************Table A15, Panel C: single IV models, unweighted *************************
*****************************************************************************************

*Export tables*
estout e1siv e2siv e3siv e4siv e5siv e6siv using  "$project/results/table_spec_single_iv.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f  %7.2f) labels("Observations" "First-stage $ F$  stat.")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )


*robot variables*
cap drop base1993* change_robots
gen base1993_stock_pc=ln(stock_robots_1993/$normalization_robots)
gen change_robots=ln(stock_robots_2014/$normalization_robots )-ln(stock_robots_1993/$normalization_robots )

***Change in logs, Panel D***
reg change_robots change_dependency base1993_stock_pc $robot_weight, r
estimates store e1

reg change_robots change_dependency base1993_stock_pc  $country_covariates $robot_weight , r
estimates store e2

reg change_robots change_dependency ln_manuf_va base1993_stock_pc  $country_covariates $robot_weight , r
estimates store e3

***Change in logs, Panel E***
ivreg2 change_robots (change_dependency=$instruments) base1993_stock_pc $robot_weight, r partial(base1993_stock_pc) ffirst
estimates store e1iv

ivreg2 change_robots (change_dependency=$instruments) base1993_stock_pc  $country_covariates $robot_weight , r  partial(base1993_stock_pc  $country_covariates) ffirst
estimates store e2iv

ivreg2 change_robots (change_dependency=$instruments) ln_manuf_va  base1993_stock_pc  $country_covariates $robot_weight , r partial(ln_manuf_va  base1993_stock_pc  $country_covariates) ffirst
estimates store e3iv

*robot variables*
cap drop base1993* change_robots new_sample
gen base1993_stock_pc=ln((stock_robots_1993+1)/$normalization_robots)
gen change_robots=ln((stock_robots_2014+1)/$normalization_robots )-ln((stock_robots_1993+1)/$normalization_robots )
quietly: reg change_robots change_dependency base1993_stock_pc i.dreg $country_covariates
gen new_sample=e(sample)

***Change in logs, Panel D***
reg change_robots change_dependency base1993_stock_pc i.dreg if new_sample==1 $robot_weight, r
estimates store e4

reg change_robots change_dependency base1993_stock_pc i.dreg $country_covariates if new_sample==1 $robot_weight, r
estimates store e5

reg change_robots change_dependency ln_manuf_va base1993_stock_pc i.dreg $country_covariates if new_sample==1 $robot_weight, r
estimates store e6

***Change in logs, Panel E***
ivreg2 change_robots (change_dependency=$instruments) base1993_stock_pc i.dreg if new_sample==1 $robot_weight, r partial(base1993_stock_pc i.dreg) ffirst
estimates store e4iv

ivreg2 change_robots (change_dependency=$instruments) base1993_stock_pc i.dreg $country_covariates if new_sample==1 $robot_weight, r partial(base1993_stock_pc i.dreg $country_covariates)  ffirst
estimates store e5iv

ivreg2 change_robots (change_dependency=$instruments) ln_manuf_va base1993_stock_pc i.dreg $country_covariates if new_sample==1 $robot_weight, r partial(ln_manuf_va base1993_stock_pc i.dreg $country_covariates) ffirst
estimates store e6iv

*****************************************************************************************	
*****************Table A15, Panel D: OLS models, weighted *******************************
*****************************************************************************************

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_spec_ols_weighted.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency )

*****************************************************************************************	
*****************Table A15, Panel E: IV models, weighted ********************************
*****************************************************************************************

*Export tables*
estout e1iv e2iv e3iv e4iv e5iv e6iv using  "$project/results/table_spec_iv_weighted.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency )

