/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A19: 	Relationship between aging and relative wages in manufacturing.
			Data from World Input Output Tables, 1995-2009
			
Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_wages_wiot14_ols.tex
			/results/table_wages_wiot14_2sls.tex
			/results/table_wages_wiot14_iv.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* covariates *	
use "${project}/clean_data/country_covariates.dta", clear

* regions *
encode new_region, gen(dreg)

* wage data from WIOT *
merge 1:1 isocode using "${project}/clean_data/ccountry_wages.dta", assert(1 3) nogenerate

* demographics data *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*sample selection*
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg if country_name!= "japan" & country_name!="russian federation" 
gen robot_sample=e(sample)
gen full_sample=1


	************************
	*******Estimation*******
	************************ 

****************************************************************************************
* Table: main and oecd samples, following specification in the main text for WIOT 14   *
****************************************************************************************
cap drop depvar* 
cap drop base* 
cap drop change_dependency* 

* wages from WIOT14 (alternative, low_manuf) *
gen depvar=(ln((w14_hrwage_manuf_2009/w14_hrwage_nonagri_2009)/(w14_hrwage_manuf_1995/w14_hrwage_nonagri_1995)))
gen base_wage=ln(w14_hrwage_manuf_1995/w14_hrwage_nonagri_1995)

* aging variables *
gen change_dependency=(dependency_55_y2025-dependency_55_y1995)
gen base_dependency=dependency_55_y1995

********************** Panel A: OLS ****************************
reg depvar change_dependency if full_sample==1, r
estimates store e1

reg depvar change_dependency $covariates_wages  base_wage i.dreg if full_sample==1, r
estimates store e2

reg depvar change_dependency if full_sample==1 & oecd_country==1, r
estimates store e3

reg depvar change_dependency $covariates_wages  base_wage if full_sample==1 & oecd_country==1, r
estimates store e4

reg depvar change_dependency if robot_sample==1, r
estimates store e5

reg depvar change_dependency $covariates_wages base_wage i.dreg if robot_sample==1, r
estimates store e6

reg depvar change_dependency if robot_sample==1 & oecd_country==1, r
estimates store e7

reg depvar change_dependency $covariates_wages base_wage if robot_sample==1 & oecd_country==1, r
estimates store e8

estout e1 e2 e3 e4 e5 e6 e7 e8 using "$project/results/table_wages_wiot14_ols.tex", style(tex) ///
varlabels(change_dependency     "Aging 1995 and 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) ///
		  nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )

********************** Panel B: 2SLS ****************************
ivreg2 depvar (change_dependency=${instruments}) if full_sample==1, r ffirst
estimates store e1

ivreg2 depvar (change_dependency=${instruments}) $covariates_wages base_wage i.dreg if full_sample==1, r partial($covariates_wages i.dreg)   ffirst
estimates store e2

ivreg2 depvar (change_dependency=${instruments}) if full_sample==1 & oecd_country==1, r    ffirst
estimates store e3

ivreg2 depvar (change_dependency=${instruments}) $covariates_wages base_wage if full_sample==1 & oecd_country==1, r partial($covariates_wages)   ffirst
estimates store e4

ivreg2 depvar (change_dependency=${instruments}) if robot_sample==1, r   ffirst
estimates store e5

ivreg2 depvar (change_dependency=${instruments}) $covariates_wages base_wage i.dreg if robot_sample==1, r partial($covariates_wages i.dreg)   ffirst
estimates store e6

ivreg2 depvar (change_dependency=${instruments}) if robot_sample==1 & oecd_country==1, r   ffirst
estimates store e7

ivreg2 depvar (change_dependency=${instruments}) $covariates_wages base_wage if robot_sample==1 & oecd_country==1, r partial($covariates_wages)  ffirst
estimates store e8

estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_wages_wiot14_2sls.tex", style(tex) ///
varlabels(change_dependency     "Aging 1995 and 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) ///
		  nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )

********************** Panel C: single IV ****************************
ivreg2 depvar (change_dependency=change_birthrate_60_80) if full_sample==1, r
estimates store e1

ivreg2 depvar (change_dependency=change_birthrate_60_80) $covariates_wages base_wage i.dreg if full_sample==1, r  partial($covariates_wages i.dreg)
estimates store e2

ivreg2 depvar (change_dependency=change_birthrate_60_80) if full_sample==1 & oecd_country==1, r
estimates store e3

ivreg2 depvar (change_dependency=change_birthrate_60_80) $covariates_wages base_wage if full_sample==1 & oecd_country==1, r  partial($covariates_wages)
estimates store e4

ivreg2 depvar (change_dependency=change_birthrate_60_80) if robot_sample==1, r
estimates store e5

ivreg2 depvar (change_dependency=change_birthrate_60_80) $covariates_wages base_wage i.dreg if robot_sample==1, r  partial($covariates_wages i.dreg) 
estimates store e6

ivreg2 depvar (change_dependency=change_birthrate_60_80) if robot_sample==1 & oecd_country==1, r
estimates store e7

ivreg2 depvar (change_dependency=change_birthrate_60_80) $covariates_wages base_wage if robot_sample==1 & oecd_country==1, r partial($covariates_wages)
estimates store e8

estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_wages_wiot14_iv.tex", style(tex) ///
varlabels(change_dependency     "Aging 1995 and 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f) ///
		  labels("Observations" "First-stage $ F$  stat."  )) ///
		  nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )


